
From: Russell King <rmk@arm.linux.org.uk>

This patch cleans up needless includes of asm/pgalloc.h from the arch/i386/
subtree.  Compile tested on x86_pc SMP.

[I also tried VISWS + SMP without PM doesn't build in smpboot.c,
 though I don't believe its caused by this patch.  With PM, fails
 to link complaining maxcpus is undefined.  Therefore, I presume
 VISWS + SMP is an invalid configuration.]

This patch is part of a larger patch aiming towards getting the include of
asm/pgtable.h out of linux/mm.h, so that asm/pgtable.h can sanely get at
things like mm_struct and friends.

I suggest testing in -mm for a while to ensure there aren't any hidden arch
issues.

The outstanding list of files for other architectures can be found
at http://www.arm.linux.org.uk/misc/pgalloc.txt


---

 25-power4-akpm/arch/i386/kernel/acpi/boot.c            |    2 +-
 25-power4-akpm/arch/i386/kernel/apic.c                 |    1 -
 25-power4-akpm/arch/i386/kernel/efi.c                  |    1 -
 25-power4-akpm/arch/i386/kernel/i386_ksyms.c           |    1 -
 25-power4-akpm/arch/i386/kernel/irq.c                  |    1 -
 25-power4-akpm/arch/i386/kernel/mpparse.c              |    1 -
 25-power4-akpm/arch/i386/kernel/smp.c                  |    1 -
 25-power4-akpm/arch/i386/kernel/smpboot.c              |    1 -
 25-power4-akpm/arch/i386/kernel/traps.c                |    1 -
 25-power4-akpm/arch/i386/kernel/vm86.c                 |    1 -
 25-power4-akpm/arch/i386/mach-visws/traps.c            |    1 -
 25-power4-akpm/arch/i386/mach-voyager/voyager_basic.c  |    1 -
 25-power4-akpm/arch/i386/mach-voyager/voyager_smp.c    |    1 -
 25-power4-akpm/arch/i386/mach-voyager/voyager_thread.c |    1 -
 25-power4-akpm/arch/i386/mm/fault.c                    |    1 -
 25-power4-akpm/arch/i386/mm/hugetlbpage.c              |    1 -
 25-power4-akpm/arch/i386/mm/init.c                     |    1 -
 25-power4-akpm/arch/i386/mm/ioremap.c                  |    1 -
 18 files changed, 1 insertion(+), 18 deletions(-)

diff -puN arch/i386/kernel/acpi/boot.c~clean-up-asm-pgalloch-include-3 arch/i386/kernel/acpi/boot.c
--- 25-power4/arch/i386/kernel/acpi/boot.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.834651832 -0700
+++ 25-power4-akpm/arch/i386/kernel/acpi/boot.c	2004-04-18 16:06:53.860647880 -0700
@@ -28,7 +28,7 @@
 #include <linux/acpi.h>
 #include <linux/efi.h>
 #include <linux/irq.h>
-#include <asm/pgalloc.h>
+#include <asm/pgtable.h>
 #include <asm/io_apic.h>
 #include <asm/apic.h>
 #include <asm/io.h>
diff -puN arch/i386/kernel/apic.c~clean-up-asm-pgalloch-include-3 arch/i386/kernel/apic.c
--- 25-power4/arch/i386/kernel/apic.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.836651528 -0700
+++ 25-power4-akpm/arch/i386/kernel/apic.c	2004-04-18 16:06:53.861647728 -0700
@@ -31,7 +31,6 @@
 #include <asm/smp.h>
 #include <asm/mtrr.h>
 #include <asm/mpspec.h>
-#include <asm/pgalloc.h>
 #include <asm/desc.h>
 #include <asm/arch_hooks.h>
 #include <asm/hpet.h>
diff -puN arch/i386/kernel/efi.c~clean-up-asm-pgalloch-include-3 arch/i386/kernel/efi.c
--- 25-power4/arch/i386/kernel/efi.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.837651376 -0700
+++ 25-power4-akpm/arch/i386/kernel/efi.c	2004-04-18 16:06:53.862647576 -0700
@@ -37,7 +37,6 @@
 #include <asm/pgtable.h>
 #include <asm/processor.h>
 #include <asm/desc.h>
-#include <asm/pgalloc.h>
 #include <asm/tlbflush.h>
 
 #define EFI_DEBUG	0
diff -puN arch/i386/kernel/i386_ksyms.c~clean-up-asm-pgalloch-include-3 arch/i386/kernel/i386_ksyms.c
--- 25-power4/arch/i386/kernel/i386_ksyms.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.839651072 -0700
+++ 25-power4-akpm/arch/i386/kernel/i386_ksyms.c	2004-04-18 16:06:53.862647576 -0700
@@ -29,7 +29,6 @@
 #include <asm/mmx.h>
 #include <asm/desc.h>
 #include <asm/pgtable.h>
-#include <asm/pgalloc.h>
 #include <asm/tlbflush.h>
 #include <asm/nmi.h>
 #include <asm/ist.h>
diff -puN arch/i386/kernel/irq.c~clean-up-asm-pgalloch-include-3 arch/i386/kernel/irq.c
--- 25-power4/arch/i386/kernel/irq.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.840650920 -0700
+++ 25-power4-akpm/arch/i386/kernel/irq.c	2004-04-18 16:06:53.863647424 -0700
@@ -41,7 +41,6 @@
 #include <asm/system.h>
 #include <asm/bitops.h>
 #include <asm/uaccess.h>
-#include <asm/pgalloc.h>
 #include <asm/delay.h>
 #include <asm/desc.h>
 #include <asm/irq.h>
diff -puN arch/i386/kernel/mpparse.c~clean-up-asm-pgalloch-include-3 arch/i386/kernel/mpparse.c
--- 25-power4/arch/i386/kernel/mpparse.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.842650616 -0700
+++ 25-power4-akpm/arch/i386/kernel/mpparse.c	2004-04-18 16:06:53.864647272 -0700
@@ -28,7 +28,6 @@
 #include <asm/acpi.h>
 #include <asm/mtrr.h>
 #include <asm/mpspec.h>
-#include <asm/pgalloc.h>
 #include <asm/io_apic.h>
 
 #include <mach_apic.h>
diff -puN arch/i386/kernel/smpboot.c~clean-up-asm-pgalloch-include-3 arch/i386/kernel/smpboot.c
--- 25-power4/arch/i386/kernel/smpboot.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.843650464 -0700
+++ 25-power4-akpm/arch/i386/kernel/smpboot.c	2004-04-18 16:06:53.865647120 -0700
@@ -47,7 +47,6 @@
 
 #include <linux/delay.h>
 #include <linux/mc146818rtc.h>
-#include <asm/pgalloc.h>
 #include <asm/tlbflush.h>
 #include <asm/desc.h>
 #include <asm/arch_hooks.h>
diff -puN arch/i386/kernel/smp.c~clean-up-asm-pgalloch-include-3 arch/i386/kernel/smp.c
--- 25-power4/arch/i386/kernel/smp.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.844650312 -0700
+++ 25-power4-akpm/arch/i386/kernel/smp.c	2004-04-18 16:06:53.866646968 -0700
@@ -21,7 +21,6 @@
 #include <linux/interrupt.h>
 
 #include <asm/mtrr.h>
-#include <asm/pgalloc.h>
 #include <asm/tlbflush.h>
 #include <mach_ipi.h>
 #include <mach_apic.h>
diff -puN arch/i386/kernel/traps.c~clean-up-asm-pgalloch-include-3 arch/i386/kernel/traps.c
--- 25-power4/arch/i386/kernel/traps.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.845650160 -0700
+++ 25-power4-akpm/arch/i386/kernel/traps.c	2004-04-18 16:06:53.867646816 -0700
@@ -47,7 +47,6 @@
 #include <asm/nmi.h>
 
 #include <asm/smp.h>
-#include <asm/pgalloc.h>
 #include <asm/arch_hooks.h>
 
 #include <linux/irq.h>
diff -puN arch/i386/kernel/vm86.c~clean-up-asm-pgalloch-include-3 arch/i386/kernel/vm86.c
--- 25-power4/arch/i386/kernel/vm86.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.847649856 -0700
+++ 25-power4-akpm/arch/i386/kernel/vm86.c	2004-04-18 16:06:53.867646816 -0700
@@ -44,7 +44,6 @@
 #include <linux/ptrace.h>
 
 #include <asm/uaccess.h>
-#include <asm/pgalloc.h>
 #include <asm/io.h>
 #include <asm/tlbflush.h>
 #include <asm/irq.h>
diff -puN arch/i386/mach-visws/traps.c~clean-up-asm-pgalloch-include-3 arch/i386/mach-visws/traps.c
--- 25-power4/arch/i386/mach-visws/traps.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.848649704 -0700
+++ 25-power4-akpm/arch/i386/mach-visws/traps.c	2004-04-18 16:06:53.868646664 -0700
@@ -8,7 +8,6 @@
 #include <linux/pci_ids.h>
 
 #include <asm/io.h>
-#include <asm/pgalloc.h>
 #include <asm/arch_hooks.h>
 #include <asm/apic.h>
 #include "cobalt.h"
diff -puN arch/i386/mach-voyager/voyager_basic.c~clean-up-asm-pgalloch-include-3 arch/i386/mach-voyager/voyager_basic.c
--- 25-power4/arch/i386/mach-voyager/voyager_basic.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.849649552 -0700
+++ 25-power4-akpm/arch/i386/mach-voyager/voyager_basic.c	2004-04-18 16:06:53.868646664 -0700
@@ -24,7 +24,6 @@
 #include <linux/reboot.h>
 #include <linux/sysrq.h>
 #include <asm/io.h>
-#include <asm/pgalloc.h>
 #include <asm/voyager.h>
 #include <asm/vic.h>
 #include <linux/pm.h>
diff -puN arch/i386/mach-voyager/voyager_smp.c~clean-up-asm-pgalloch-include-3 arch/i386/mach-voyager/voyager_smp.c
--- 25-power4/arch/i386/mach-voyager/voyager_smp.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.851649248 -0700
+++ 25-power4-akpm/arch/i386/mach-voyager/voyager_smp.c	2004-04-18 16:06:53.869646512 -0700
@@ -24,7 +24,6 @@
 #include <asm/desc.h>
 #include <asm/voyager.h>
 #include <asm/vic.h>
-#include <asm/pgalloc.h>
 #include <asm/mtrr.h>
 #include <asm/pgalloc.h>
 #include <asm/tlbflush.h>
diff -puN arch/i386/mach-voyager/voyager_thread.c~clean-up-asm-pgalloch-include-3 arch/i386/mach-voyager/voyager_thread.c
--- 25-power4/arch/i386/mach-voyager/voyager_thread.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.852649096 -0700
+++ 25-power4-akpm/arch/i386/mach-voyager/voyager_thread.c	2004-04-18 16:06:53.870646360 -0700
@@ -28,7 +28,6 @@
 #include <asm/desc.h>
 #include <asm/voyager.h>
 #include <asm/vic.h>
-#include <asm/pgalloc.h>
 #include <asm/mtrr.h>
 #include <asm/msr.h>
 
diff -puN arch/i386/mm/fault.c~clean-up-asm-pgalloch-include-3 arch/i386/mm/fault.c
--- 25-power4/arch/i386/mm/fault.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.853648944 -0700
+++ 25-power4-akpm/arch/i386/mm/fault.c	2004-04-18 16:06:53.870646360 -0700
@@ -24,7 +24,6 @@
 
 #include <asm/system.h>
 #include <asm/uaccess.h>
-#include <asm/pgalloc.h>
 #include <asm/hardirq.h>
 #include <asm/desc.h>
 
diff -puN arch/i386/mm/hugetlbpage.c~clean-up-asm-pgalloch-include-3 arch/i386/mm/hugetlbpage.c
--- 25-power4/arch/i386/mm/hugetlbpage.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.854648792 -0700
+++ 25-power4-akpm/arch/i386/mm/hugetlbpage.c	2004-04-18 16:06:53.871646208 -0700
@@ -16,7 +16,6 @@
 #include <linux/err.h>
 #include <linux/sysctl.h>
 #include <asm/mman.h>
-#include <asm/pgalloc.h>
 #include <asm/tlb.h>
 #include <asm/tlbflush.h>
 
diff -puN arch/i386/mm/init.c~clean-up-asm-pgalloch-include-3 arch/i386/mm/init.c
--- 25-power4/arch/i386/mm/init.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.856648488 -0700
+++ 25-power4-akpm/arch/i386/mm/init.c	2004-04-18 16:06:53.871646208 -0700
@@ -32,7 +32,6 @@
 #include <asm/system.h>
 #include <asm/uaccess.h>
 #include <asm/pgtable.h>
-#include <asm/pgalloc.h>
 #include <asm/dma.h>
 #include <asm/fixmap.h>
 #include <asm/e820.h>
diff -puN arch/i386/mm/ioremap.c~clean-up-asm-pgalloch-include-3 arch/i386/mm/ioremap.c
--- 25-power4/arch/i386/mm/ioremap.c~clean-up-asm-pgalloch-include-3	2004-04-18 16:06:53.857648336 -0700
+++ 25-power4-akpm/arch/i386/mm/ioremap.c	2004-04-18 16:06:53.872646056 -0700
@@ -12,7 +12,6 @@
 #include <linux/init.h>
 #include <linux/slab.h>
 #include <asm/io.h>
-#include <asm/pgalloc.h>
 #include <asm/fixmap.h>
 #include <asm/cacheflush.h>
 #include <asm/tlbflush.h>

_
